--[[ ArenaLive Core Functions: Role Icon Handler
Created by: Vadrak
Creation Date: 31.01.2015
Last Update: "
This basically is a copy-paste of the regular role icon in order to show a custom role texture.
]]--

-- ArenaLive addon Name and localisation table:
local addonName, L = ...;

--[[
**************************************************
******* GENERAL HANDLER SET UP STARTS HERE *******
**************************************************
]]--
local SpecIcon = ArenaLive:ConstructHandler("TalentSpecialisationIcon", true);
SpecIcon:RegisterEvent("AL_SPEC_PLAYER_SPECIALIZATION_UPDATE");
SpecIcon:RegisterEvent("UPDATE_BATTLEFIELD_STATUS");

--[[
****************************************
****** HANDLER METHODS START HERE ******
****************************************
]]--
function SpecIcon:Update(unitFrame)
	local unit = unitFrame.unit;
	local icon = unitFrame[self.name];
	if ( not unit or not icon ) then
		return;
	end
	
	local specID = ArenaLiveSpectator.UnitCache:GetUnitSpecialisation(unit);
	if ( specID ) then
		local _, _, _, texture = GetSpecializationInfoByID(specID);
		if ( texture ) then
			icon:Show();
			icon:SetTexture(texture);
		else
			self:Reset(unitFrame);
		end
	else
		self:Reset(unitFrame);
	end
end


function SpecIcon:Reset(unitFrame)
	local icon = unitFrame[self.name];
	icon:Hide();
end

function SpecIcon:OnEvent(event, ...)
	local filter  = ...;
	if ( event == "AL_SPEC_PLAYER_SPECIALIZATION_UPDATE" and self.enabled ) then
		if ( ArenaLive:IsUnitInUnitFrameCache(filter) ) then
			for id in ArenaLive:GetAffectedUnitFramesByUnit(filter) do
				local unitFrame = ArenaLive:GetUnitFrameByID(id);
				if ( unitFrame[self.name] ) then
					SpecIcon:Update(unitFrame);
				end
			end
		end
	elseif ( event == "UPDATE_BATTLEFIELD_STATUS" ) then
		local status = GetBattlefieldStatus(filter);
		local isSpectator, queueType = IsSpectator();
		if( status == "active" and isSpectator and queueType == "battleground" ) then
			self.enabled = true;
			for id, unitFrame in ArenaLive:GetAllUnitFrames() do
				if ( frame.enabled and unitFrame[self.name] ) then
					SpecIcon:Update(unitFrame);
				end
			end
		elseif ( status == "none" ) then
			self.enabled = false;
		end
	end
end