local addonName, L = ...;

function BGLiveScoreBoard:Initialise()
	local database = ArenaLive:GetDBComponent(addonName);
	local aRed, aGreen, aBlue, aAlpha = unpack(database.TeamA.Colour);
	local bRed, bGreen, bBlue, bAlpha = unpack(database.TeamB.Colour);
	BGLiveScoreBoardTeamABackground:SetVertexColor(aRed, aGreen, aBlue, aAlpha);
	BGLiveScoreBoardTeamBBackground:SetVertexColor(bRed, bGreen, bBlue, bAlpha);
	
	-- Initialise names and scores:
	self:UpdateTeamName("TeamA");
	self:UpdateTeamScore("TeamA");
	
	self:UpdateTeamName("TeamB");
	self:UpdateTeamScore("TeamB");
	
	-- Initialise Statusbars:
	local statusBar = BGLiveScoreBoardTeamAPoints:GetStatusBarTexture();
	BGLiveScoreBoardTeamAPoints:SetStatusBarColor(aRed, aGreen, aBlue, aAlpha);
	BGLiveScoreBoardTeamAPoints:SetReverseFill(true);
	BGLiveScoreBoardTeamAPointsSpark:ClearAllPoints();
	BGLiveScoreBoardTeamAPointsSpark:SetPoint("CENTER", statusBar, "LEFT", 0, 0);
	BGLiveScoreBoardTeamAPointsSpark:SetVertexColor(aRed, aGreen, aBlue, aAlpha);
	
	statusBar = BGLiveScoreBoardTeamBPoints:GetStatusBarTexture();
	BGLiveScoreBoardTeamBPoints:SetStatusBarColor(bRed, bGreen, bBlue, bAlpha);
	BGLiveScoreBoardTeamBPointsSpark:ClearAllPoints();
	BGLiveScoreBoardTeamBPointsSpark:SetPoint("CENTER", statusBar, "RIGHT", 0, 0);
	BGLiveScoreBoardTeamBPointsSpark:SetVertexColor(bRed, bGreen, bBlue, bAlpha);
	
	BGLiveScoreBoard:UpdatePoints();
	
	-- Initialise timer:
	BGLiveScoreBoard:UpdateTimer();
	
	-- Set Scripts:
	self:RegisterForClicks("RightButtonUp");
	self:SetScript("OnClick", self.OnClick);
end

function BGLiveScoreBoard:OnClick(button, down)
	if ( button == "RightButton" and not down ) then
		if ( BGLive.swapTeams ) then
			BGLive.swapTeams = false;
		else
			BGLive.swapTeams = true;
		end
		
		BGLiveScoreBoard:Update();
	end
end

function BGLiveScoreBoard:UpdateTeamScore(team)
	local scoreText;
	if ( team == "TeamA" or team == "TeamB" ) then
		scoreText = _G["BGLiveScoreBoard"..team.."Score"];
	else
		return;
	end	
	
	if ( BGLive.swapTeams ) then
		if ( team == "TeamA" ) then
			team = "TeamB";
		else
			team = "TeamA";
		end
	end
	
	local database = ArenaLive:GetDBComponent(ArenaLiveSpectator.name, nil, team);
	scoreText:SetText(database.Score);
end

function BGLiveScoreBoard:UpdateTeamName(team)
	local name;
	if ( team == "TeamA" or team == "TeamB" ) then
		name = _G["BGLiveScoreBoard"..team.."Name"];
	else
		return;
	end	
	
	if ( BGLive.swapTeams ) then
		if ( team == "TeamA" ) then
			team = "TeamB";
		else
			team = "TeamA";
		end
	end	
	
	local database = ArenaLive:GetDBComponent(ArenaLiveSpectator.name, nil, team);
	name:SetText(database.Name);
end

function BGLiveScoreBoard:Update()
	BGLiveScoreBoard:UpdateTeamName("TeamA");
	BGLiveScoreBoard:UpdateTeamName("TeamB");
	BGLiveScoreBoard:UpdateTeamScore("TeamA");
	BGLiveScoreBoard:UpdateTeamScore("TeamB");
end

function BGLiveScoreBoard:UpdateTimer()
	if ( not BGLive.worldStateTimerIndex ) then
		BGLiveScoreBoardTimerBackground:Hide();
		BGLiveScoreBoardTimer:Hide();
	else
		local uiType, state, _, text = GetWorldStateUIInfo(BGLive.worldStateTimerIndex);
		local minutes, seconds = string.match(text,("([0-9]+):([0-9]+)$"));
		local text = minutes..":"..seconds;
		BGLiveScoreBoardTimerBackground:Show();
		BGLiveScoreBoardTimer:Show();
		BGLiveScoreBoardTimer:SetText(text);
	end
end

function BGLiveScoreBoard:Reset()
	self.hordeWorldState = nil;
	self.allianceWorldState = nil;
	BGLiveScoreBoardTeamAPoints:SetMinMaxValues(0, 1);
	BGLiveScoreBoardTeamAPoints:SetValue(0);
	BGLiveScoreBoardTeamAPointsText:SetText(string.format(L["%d/%d"], 0, 1));
	
	BGLiveScoreBoardTeamBPoints:SetMinMaxValues(0, 1);
	BGLiveScoreBoardTeamBPoints:SetValue(0);
	BGLiveScoreBoardTeamBPointsText:SetText(string.format(L["%d/%d"], 0, 1));
	
	BGLiveScoreBoardTimer:SetText("00:00");
end

function BGLiveScoreBoard:UpdatePoints()
	local mapID = BGLive:GetCurrentMapID();
	local hordePoints, hordeMaxPoints = GetBattlegroundPoints(0);
	local alliancePoints, allianceMaxPoints = GetBattlegroundPoints(1);
	
	if ( mapID == 30 or mapID == 628 or mapID == 998 or mapID == 727 ) then
		if ( not self.allianceWorldState or not self.hordeWorldState ) then
			for i = 1, GetNumWorldStateUI() do
				if ( select(5,GetWorldStateUIInfo(i)) == "Interface\\TargetingFrame\\UI-PVP-Alliance" ) then
					self.allianceWorldState = i;
				elseif ( select(5,GetWorldStateUIInfo(i)) == "Interface\\TargetingFrame\\UI-PVP-Horde" ) then
					self.hordeWorldState = i;
				end
			end
		end
		
		local text;
		if ( self.allianceWorldState ) then
			text = select(4, GetWorldStateUIInfo(self.allianceWorldState));
			if ( text ) then
				if ( mapID == 998 ) then
					alliancePoints, allianceMaxPoints = string.match(text, L["^Victory Points: (%d+)/(%d+)$"]);
				elseif ( mapID == 727 ) then
					alliancePoints, allianceMaxPoints = string.match(text, L["^Resources: (%d+)/(%d+)$"]);
				elseif ( mapID == 628 ) then
					alliancePoints, allianceMaxPoints = tonumber(string.match(text, L["^Reinforcements: (%d+)$"])) or 0, 300;
				else
					alliancePoints, allianceMaxPoints = tonumber(string.match(text, L["^Reinforcements: (%d+)$"])) or 0, 600;
				end
				alliancePoints, allianceMaxPoints = tonumber(alliancePoints), tonumber(allianceMaxPoints);
				if ( alliancePoints > allianceMaxPoints ) then
					allianceMaxPoints = alliancePoints;
				end
			else
				alliancePoints, allianceMaxPoints = 0, 0;
			end
		end
		if ( self.hordeWorldState ) then
			text = select(4, GetWorldStateUIInfo(self.hordeWorldState));
			if ( text ) then
				if ( mapID == 998 ) then
					hordePoints, hordeMaxPoints = string.match(text, L["^Victory Points: (%d+)/(%d+)$"]);
				elseif ( mapID == 727 ) then
					hordePoints, hordeMaxPoints = string.match(text, L["^Resources: (%d+)/(%d+)$"]);
				elseif ( mapID == 628 ) then
					hordePoints, hordeMaxPoints = tonumber(string.match(text, L["^Reinforcements: (%d+)$"])) or 0, 300;
				else
					hordePoints, hordeMaxPoints = tonumber(string.match(text, L["^Reinforcements: (%d+)$"])) or 0, 600;
				end
				
				hordePoints, hordeMaxPoints = tonumber(hordePoints), tonumber(hordeMaxPoints);
				if ( hordePoints > hordeMaxPoints ) then
					hordeMaxPoints = hordePoints;
				end
			else
				hordePoints, hordeMaxPoints = 0, 0;
			end
		end	
	end
	
	BGLiveScoreBoardTeamAPoints:SetMinMaxValues(0, allianceMaxPoints);
	BGLiveScoreBoardTeamAPoints:SetValue(alliancePoints);
	
	BGLiveScoreBoardTeamBPoints:SetMinMaxValues(0, hordeMaxPoints);
	BGLiveScoreBoardTeamBPoints:SetValue(hordePoints);
	
	
	local allianceText, hordeText;
	if ( mapID == 489 or mapID == 726 ) then
		allianceText = string.format(L["Flags Captured: %d/%d"], alliancePoints, allianceMaxPoints);
		hordeText = string.format(L["Flags Captured: %d/%d"], hordePoints, hordeMaxPoints);		
	elseif ( mapID == 529 or mapID == 566 or mapID == 968 or mapID == 761 or mapID == 727 ) then
		allianceText = string.format(L["Resources: %d/%d"], alliancePoints, allianceMaxPoints);
		hordeText = string.format(L["Resources: %d/%d"], hordePoints, hordeMaxPoints);		
	elseif ( mapID == 998 ) then
		allianceText = string.format(L["Victory Points: %d/%d"], alliancePoints, allianceMaxPoints);
		hordeText = string.format(L["Victory Points: %d/%d"], hordePoints, hordeMaxPoints);
	elseif ( mapID == 1105 ) then
		allianceText = string.format(L["Gold: %d/%d"], alliancePoints, allianceMaxPoints);
		hordeText = string.format(L["Gold: %d/%d"], hordePoints, hordeMaxPoints);
	elseif ( mapID == 30 or mapID == 628  ) then
		allianceText = string.format(L["Reinforcements: %d/%d"], alliancePoints, allianceMaxPoints);
		hordeText = string.format(L["Reinforcements: %d/%d"], hordePoints, hordeMaxPoints);
	else
		allianceText = string.format(L["%d/%d"], alliancePoints, allianceMaxPoints);
		hordeText = string.format(L["%d/%d"], hordePoints, hordeMaxPoints);
	end
	
	BGLiveScoreBoardTeamAPointsText:SetText(allianceText);
	BGLiveScoreBoardTeamBPointsText:SetText(hordeText);
end