local addonName, L = ...;
local function UpdateBorderColour(self)
	local prefix = self:GetName();
	local border = _G[prefix.."Border"];
	
	if ( self.unit ) then
		local unitType = string.match(self.unit, "^([a-z]+)[0-9]+$") or self.unit;
		local database = ArenaLive:GetDBComponent(addonName);
		local factionGroup = UnitFactionGroup(self.unit);
		local red, green, blue, alpha;
		if ( unitType == "spectateda" or factionGroup == "Alliance" ) then
			red, green, blue, alpha = unpack(database.TeamA.Colour);
		elseif ( unitType == "spectatedb" or factionGroup == "Horde" ) then
			red, green, blue, alpha = unpack(database.TeamB.Colour);
		else
			red, green, blue, alpha = 1, 1, 1, 1; -- Mostly testing purposes.
		end
		
		border:SetVertexColor(red, green, blue, alpha);
	else
		border:SetVertexColor(1, 1, 1, 1);
	end
end

local function InitialiseSingle(self)
	local prefix = self:GetName();
	self.UpdateBorderColour = UpdateBorderColour;
	ArenaLive:ConstructHandlerObject(self, "UnitFrame", addonName, "SideFrames", "target", nil);
	
	-- Register Frame constituents:
	self:RegisterHandler(_G[prefix.."HealthBar"], "HealthBar", nil, _G[prefix.."HealthBarHealPredictionBar"], _G[prefix.."HealthBarAbsorbBar"], _G[prefix.."HealthBarAbsorbBarOverlay"], 32, _G[prefix.."HealthBarAbsorbBarFullHPIndicator"], nil, addonName, "SideFrames");
		self:RegisterHandler(_G[prefix.."HealthBarText"], "HealthBarText", nil, self);
	self:RegisterHandler(_G[prefix.."Icon1"], "Icon", 1, _G[prefix.."Icon1Texture"],_G[prefix.."Icon1Cooldown"], addonName);
	self:RegisterHandler(_G[prefix.."Icon2"], "Icon", 2, _G[prefix.."Icon2Texture"], _G[prefix.."Icon2Cooldown"], addonName);
	self:RegisterHandler(_G[prefix.."Name"], "NameText", nil, self);
	self:RegisterHandler(_G[prefix.."Portrait"], "Portrait", nil, _G[prefix.."PortraitBackground"], _G[prefix.."PortraitTexture"],  _G[prefix.."PortraitThreeD"], self);
	self:RegisterHandler(_G[prefix.."PortraitCCIndicator"], "CCIndicator", nil, _G[prefix.."PortraitCCIndicatorTexture"], _G[prefix.."PortraitCCIndicatorCooldown"], addonName);
	self:RegisterHandler(_G[prefix.."PowerBar"], "PowerBar", nil, addonName, "SideFrames");
		self:RegisterHandler(_G[prefix.."PowerBarText"], "PowerBarText", nil, self);
	self:RegisterHandler(_G[prefix.."TargetIndicator"], "TargetIndicator");
	self:RegisterHandler(_G[prefix.."SpecIcon"], "TalentSpecialisationIcon");

end

function BGLive:InitialiseSideFrames()
	for i = 1, 10 do
		local frame = _G["BGLiveLeftFramesFrame"..i];
		InitialiseSingle(frame);
		
		frame = _G["BGLiveRightFramesFrame"..i];
		InitialiseSingle(frame);
	end
end

function BGLive:EnableSideFrames()
	for i = 1, 10 do
		local frame = _G["BGLiveLeftFramesFrame"..i];
		local unit = "spectateda"..i;
		frame:Enable();
		frame:UpdateUnit(unit);
		frame:UpdateBorderColour();
		
		frame = _G["BGLiveRightFramesFrame"..i];
		unit = "spectatedb"..i;
		frame:Enable();
		frame:UpdateUnit(unit);
		frame:UpdateBorderColour();
	end
end

function BGLive:DisableSideFrames()
	for i = 1, 10 do
		local frame = _G["BGLiveLeftFramesFrame"..i];
		frame:Disable();
		
		frame = _G["BGLiveRightFramesFrame"..i];
		frame:Disable();
	end
end

function BGLive:UpdateSideFrameByUnit(unit, state)
	if ( not unit ) then
		return;
	end
	
	local unitType, unitNumber = string.match(unit, "^([a-z]+)([0-9]+)$");
	if ( unitType and unitNumber ) then
		local frame;
		if ( unitType == "spectateda" ) then
			frame = _G["BGLiveLeftFramesFrame"..unitNumber];
		elseif ( unitType == "spectatedb" ) then
			frame = _G["BGLiveRightFramesFrame"..unitNumber];
		end
		
		if ( frame ) then
			--ArenaLive:Message("Updating side frame GUID for frame %s. unit = %s, state = %s", "debug", tostring(frame:GetName()), unit, tostring(state));
			frame:UpdateGUID();
			if ( state ) then
				frame:Update();
			else
				frame:Reset();
			end
		end
	end
end

function BGLive:UpdateSideFrames()
	for i = 1, 10 do
		local frame = _G["BGLiveLeftFramesFrame"..i];
		frame:UpdateGUID();
		frame:Update();
		
		frame = _G["BGLiveRightFramesFrame"..i];
		frame:UpdateGUID();
		frame:Update();
	end
end